
% The function receives an array of 100 values and takes a rolling 
% average of each three consecutive elements. Each average represents the
% mean of mf rates received as input to a field and the two flanking fields 
% (in a row of 100 fields).

function output = rolling_average(x)

% The function reshape(x,n,m) receives an array x and returns a matrix of
% n rows and m columns. The first column is made up of the first n elements
% of the input array, the second is made up of the second n elements, and
% so on. 

x = x(1:end - 1); % remove last element so x is divisible by 3

% The first value of the input array, representing input to the first field 
% in a row of 100, does not have a field to the left, and the last one 
% does not have a field to the right, so the array is treated as if the 
% values form a circle. 

x = [x(end), x]; % put a copy of the last element at the front and...
x = x(1:end - 1); % ...remove it from the end. The reason is so that the 
% first element of the array returned as output of the function represents
% a three-field average for the first element of x, rather than the second
% element of x, which it would be otherwise.

makegps1 = reshape(x, [], 33); % create a 3 x 33 matrix
gps1_av = mean(makegps1); % Average the values in each column, creating 
% an array with m elements (here 33). 

% Duplicate the first element of the input array at the end, then remove the
% first element, so that the elements are rotated by 1. (This puts the
% first element at the back again, where it started.)

x(end+1) = x(1);
shiftby1 = x(2:end);

% Then make a matrix out of the rotated array, and average the values in
% each column, creating a second new array of 33 elements. 

makegps2 = reshape(shiftby1, [], 33);
gps2_av = mean(makegps2);

% Then rotate again.

shiftby1(end+1) = shiftby1(1);
shiftby2 = shiftby1(2:end);

% Repeat.

makegps3 = reshape(shiftby2, [], 33);
gps3_av = mean(makegps3);

% Stack the new arrays to create a 3 by 33 matrix.

output = [gps1_av;gps2_av;gps3_av];

% Turn the matrix into an array, such that the first column becomes 
% elements 1-3, the second become elements 4-6, and so on.

output = output(:)';

output = [output mean(output)]; % add back an extra element so that output 
% array is 100 elements long

