
% The function receives a 10 x 100 matrix, samples each group of three 
% columns (sample size 700), rotates the columns by 1, samples again, 
% rotates, and samples again. Each set of samples represents inhibition of 
% glomeruli by G-cells in that field and the two neighbouring fields. It
% returns a 700 x 100 matrix

function output = sample_threeflds(x)

% The function reshape(x,[],m) receives a matrix x and returns a matrix of
% m columns. As used here, it combines the first 3 columns of x into the
% first column of the new matrix, the second 3 columns into the second
% column of the new matrix, and so on. But first... 

x(:,end) = []; % remove last column so the remaining number of columns is 
% divisible by 3

% The first column of the input matrix, representing the first field 
% in a row of 100, does not have a field to the left, and the last one 
% doesn't have a field to the right, so the matrix is treated as if the 
% columns form a circle. 

x = [x(:,end), x]; % put a copy of the last column at the front and...
x(:,end) = []; % ...remove it from the end. The reason is so that the 
% first sample represents G-cell input to the first field (as represented 
% the first column) of the input matrix, rather than the second, which it
% would be otherwise.

gps1 = reshape(x, [], 33); % reshape x to create a 30 x 33 matrix
A1 = zeros(700,1); % preallocate storage space for a 700 x 1 matrix
A2 = zeros(700,33); % preallocate storage space for a 700 x 33 matrix

i = 1;
while i <= 33
    for k = 1:700
        sample = datasample(gps1(:,i),randi([8 12],1),'Replace',false); 
        % sample = datasample(gps1(:,i),24,'Replace',false); 
        samplemean = mean(sample);
        A1(k,:) = samplemean;
    end
    A2(:,i) = A1;
    i = i + 1;
end

% Duplicate the first column of x at the end, then remove the first column,
% so that the columns are rotated by 1.

x = [x, x(:,1)];
x(:,1) = [];

% Then make a second reshaped matrix and, again, take 700 samples of each
% column, sample size 10, and store the sample means as a second 700 x 33 
% matrix 

gps2 = reshape(x, [], 33); % reshape x again to create a new 30 x 33 matrix
B1 = zeros(700,1); % preallocate storage space
B2 = zeros(700,33); % preallocate storage space

i = 1;
while i <= 33
    for k = 1:700
        sample = datasample(gps2(:,i),randi([8 12],1),'Replace',false); 
        % sample = datasample(gps2(:,i),24,'Replace',false);
        samplemean = mean(sample);
        B1(k,:) = samplemean;
    end
    B2(:,i) = B1;
    i = i + 1;
end

% Then rotate again.

x = [x, x(:,1)];
x(:,1) = [];

% Repeat.

gps3 = reshape(x, [], 33); % reshape x again
C1 = zeros(700,1); 
C2 = zeros(700,33); 

i = 1;
while i <= 33
    for k = 1:700
        sample = datasample(gps1(:,i),randi([8 12],1),'Replace',false); 
        % sample = datasample(gps1(:,i),24,'Replace',false); 
        samplemean = mean(sample);
        C1(k,:) = samplemean;
    end
    C2(:,i) = C1;
    i = i + 1;
end

% Concatonate the samples to create a 700 by 99 matrix.

output = [A2, B2, C2]; % a 700 x 99 matrix

% Duplicate the first column at the end to restore the number of columns 
% to 100.

output = [output, output(:,1)]; % voila, a 700 x 100 matrix, representing 
% 700 glomeruli in each of 100 fields, and more specifically a proxy for
% GABA spillover concentration in each glomerulus


